'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GeoJSONTransform = undefined;

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();
/* eslint class-methods-use-this: 0 */


exports.getLuma = getLuma;
exports.getTheme = getTheme;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var L = require('leaflet');

L.Icon.Default.imagePath = '../node_modules/leaflet/dist/images/';

var MIMETYPE = 'application/geo+json';

function getLuma(el) {
  // https://en.wikipedia.org/wiki/Luma_(video)
  var style = window.getComputedStyle(el);

  var _style$backgroundColo = style.backgroundColor.replace(/^(rgb|rgba)\(/, '').replace(/\)$/, '').replace(/\s/g, '').split(','),
      _style$backgroundColo2 = _slicedToArray(_style$backgroundColo, 3),
      r = _style$backgroundColo2[0],
      g = _style$backgroundColo2[1],
      b = _style$backgroundColo2[2];

  // Digital ITU BT.601
  // http://www.itu.int/rec/R-REC-BT.601


  var y = 0.299 * r + 0.587 * g + 0.114 * b;
  return y / 255;
}

function getTheme() {
  var theme = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'light';
  var el = arguments[1];

  switch (theme) {
    case 'light':
    case 'dark':
      return theme;
    default:
      if (getLuma(el) < 0.5) {
        return 'dark';
      }
      return 'light';
  }
}

var GeoJSONTransform = exports.GeoJSONTransform = function (_React$Component) {
  _inherits(GeoJSONTransform, _React$Component);

  function GeoJSONTransform() {
    _classCallCheck(this, GeoJSONTransform);

    return _possibleConstructorReturn(this, (GeoJSONTransform.__proto__ || Object.getPrototypeOf(GeoJSONTransform)).apply(this, arguments));
  }

  _createClass(GeoJSONTransform, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.map = L.map(this.el);
      this.map.scrollWheelZoom.disable();

      var theme = getTheme(this.props.theme, this.el);

      this.tileLayer = L.tileLayer('https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpandmbXliNDBjZWd2M2x6bDk3c2ZtOTkifQ._QA7i5Mpkd_m30IGElHziw', {
        attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
        id: 'mapbox.' + theme
      }).addTo(this.map);

      var geoJSON = this.props.data;

      this.geoJSONLayer = L.geoJson(geoJSON).addTo(this.map);
      this.map.fitBounds(this.geoJSONLayer.getBounds());
    }
  }, {
    key: 'shouldComponentUpdate',
    value: function shouldComponentUpdate(nextProps) {
      if (nextProps.theme !== this.props.theme || this.props.data !== nextProps.data) {
        return true;
      }
      return false;
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      if (prevProps.theme !== this.props.theme) {
        var _theme = getTheme(this.props.theme, this.el);
        this.map.removeLayer(this.tileLayer);
        this.tileLayer = L.tileLayer('https://api.tiles.mapbox.com/v4/{id}/{z}/{x}/{y}.png?access_token=pk.eyJ1IjoibWFwYm94IiwiYSI6ImNpandmbXliNDBjZWd2M2x6bDk3c2ZtOTkifQ._QA7i5Mpkd_m30IGElHziw', {
          attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a>',
          id: 'mapbox.' + _theme
        }).addTo(this.map);
      }

      if (prevProps.data !== this.props.data) {
        var geoJSON = this.props.data;

        this.map.removeLayer(this.geoJSONLayer);
        this.geoJSONLayer = L.geoJson(geoJSON).addTo(this.map);
        this.map.fitBounds(this.geoJSONLayer.getBounds());
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this2 = this;

      return _react2.default.createElement(
        'div',
        null,
        _react2.default.createElement('link', {
          rel: 'stylesheet',
          href: '../node_modules/leaflet/dist/leaflet.css'
        }),
        _react2.default.createElement('div', {
          ref: function ref(el) {
            _this2.el = el;
          },
          style: { height: '600px', width: '100%' }
        })
      );
    }
  }]);

  return GeoJSONTransform;
}(_react2.default.Component);

GeoJSONTransform.defaultProps = { theme: 'light' };
GeoJSONTransform.MIMETYPE = MIMETYPE;
exports.default = GeoJSONTransform;